@@ -7,16 +7,20 @@ with qw(Geometry::Primitive::Shape MooseX::Clone);
 
 use overload ('""' => 'to_string');
 
+use Geometry::Primitive::Point;
+
 has 'start' => (
     is => 'rw',
     isa => 'Geometry::Primitive::Point',
-    required => 1
+    required => 1,
+    coerce => 1
 );
 
 has 'end' => (
     is => 'rw',
     isa => 'Geometry::Primitive::Point',
-    required => 1
+    required => 1,
+    coerce => 1
 );
 
 sub contains_point {
